import { debug } from '@linaria/logger';
import { removeWithRelated, syncResolve } from '@linaria/utils';
import { prepareForEvalSync } from '../transform-stages/1-prepare-for-eval';
import evalStage from '../transform-stages/2-eval';
import processTemplateExpression from '../utils/processTemplateExpression';
import withLinariaMetadata from '../utils/withLinariaMetadata';
export default function collector(babel, options) {
  const codeCache = new Map();
  const resolveCache = new Map();
  const evalCache = new Map();
  return {
    name: '@linaria/babel/babel-transform',

    pre(file) {
      debug('babel-transform:start', file.opts.filename);
      const entryPoint = {
        name: file.opts.filename,
        code: file.code,
        only: ['__linariaPreval']
      };
      const prepareStageResults = prepareForEvalSync(babel, resolveCache, codeCache, syncResolve, entryPoint, {
        root: file.opts.root ?? undefined,
        pluginOptions: options
      });

      if (!prepareStageResults || prepareStageResults.every(r => !withLinariaMetadata(r.metadata))) {
        return;
      }

      const evalStageResult = evalStage(resolveCache, codeCache, evalCache, prepareStageResults.map(r => r.code), {
        filename: file.opts.filename,
        pluginOptions: options
      });

      if (evalStageResult === null) {
        return;
      }

      const [valueCache] = evalStageResult;
      file.path.traverse({
        // TODO: process transformed literals
        Identifier: p => {
          processTemplateExpression(p, file.opts, options, processor => {
            processor.build(valueCache);
            processor.doRuntimeReplacement();
          });
        }
      }); // We can remove __linariaPreval export and all related code

      const prevalExport = file.path.scope.getData('__linariaPreval')?.findParent(p => p.isExpressionStatement());

      if (prevalExport) {
        removeWithRelated([prevalExport]);
      }
    },

    visitor: {},

    post(file) {
      debug('babel-transform:end', file.opts.filename);
    }

  };
}
//# sourceMappingURL=babel-transform.js.map