import cosmiconfig from 'cosmiconfig';
const explorer = cosmiconfig('linaria');
const cache = new WeakMap();
export default function loadLinariaOptions(overrides = {}) {
  if (cache.has(overrides)) {
    return cache.get(overrides);
  }

  const {
    configFile,
    ignore,
    rules,
    babelOptions = {},
    ...rest
  } = overrides;
  const result = configFile !== undefined ? explorer.loadSync(configFile) : explorer.searchSync();
  const options = {
    displayName: false,
    evaluate: true,
    extensions: ['.json', '.js', '.jsx', '.ts', '.tsx'],
    rules: rules ?? [{
      action: require.resolve('@linaria/shaker')
    }, {
      // The old `ignore` option is used as a default value for `ignore` rule.
      test: ignore ?? /[\\/]node_modules[\\/]/,
      action: 'ignore'
    }, {
      // Do not ignore ES-modules
      test: (filename, code) => {
        if (!/\/node_modules\//.test(filename)) {
          return false;
        }

        return /(?:^|\n|;)\s*(?:export|import)\s+/.test(code);
      },
      action: require.resolve('@linaria/shaker')
    }],
    babelOptions,
    ...(result ? result.config : null),
    ...rest
  };
  cache.set(overrides, options);
  return options;
}
//# sourceMappingURL=loadLinariaOptions.js.map