/**
 * This is a custom implementation for the module system for evaluating code,
 * used for resolving values for dependencies interpolated in `css` or `styled`.
 *
 * This serves 2 purposes:
 * - Avoid leakage from evaluated code to module cache in current context, e.g. `babel-register`
 * - Allow us to invalidate the module cache without affecting other stuff, necessary for rebuilds
 *
 * We also use it to transpile the code with Babel by default.
 * We also store source maps for it to provide correct error stacktraces.
 *
 */
import type { BabelFileResult } from '@babel/core';
import type { CustomDebug } from '@linaria/logger';
import type { BaseProcessor } from '@linaria/tags';
import type { StrictOptions } from '@linaria/utils';
import type { CodeCache } from './types';
declare class Module {
    #private;
    private resolveCache;
    private codeCache;
    private evalCache;
    private debuggerDepth;
    private parentModule?;
    static invalidate: () => void;
    static invalidateEvalCache: () => void;
    static _resolveFilename: (id: string, options: {
        id: string;
        filename: string;
        paths: string[];
    }) => string;
    static _nodeModulePaths: (filename: string) => string[];
    readonly idx: number;
    id: string;
    filename: string;
    options: StrictOptions;
    imports: Map<string, string[]> | null;
    paths: string[];
    extensions: string[];
    dependencies: string[] | null;
    tagProcessors: BaseProcessor[];
    transform: ((text: string) => BabelFileResult | null) | null;
    debug: CustomDebug;
    constructor(filename: string, options: StrictOptions, resolveCache: Map<string, string>, codeCache: CodeCache, evalCache: Map<string, Module>, debuggerDepth?: number, parentModule?: Module | undefined);
    get exports(): unknown;
    set exports(value: unknown);
    resolve: (id: string) => string;
    require: {
        (id: string): any;
        resolve: (id: string) => string;
        ensure: () => void;
    };
    evaluate(arg: string | string[]): void;
}
export default Module;
